@@ -520,6 +520,19 @@ def _extract_constraints(
                         },
                     }
                 )
+        elif isinstance(head, expressions.Equality):
+            # equal is ≤ and ≥, not equal is < and >
+            ops = [operators.ComparisonOperator.LE, operators.ComparisonOperator.GE]
+            if head.operator is operators.EqualityOperator.NEQ:
+                ops = [operators.ComparisonOperator.LT, operators.ComparisonOperator.GT]
+
+            pending.extend(
+                [
+                    expressions.Comparison(ops[0], head.left, head.right),
+                    expressions.Comparison(ops[1], head.left, head.right),
+                ]
+            )
+
         else:
             conjuncts.append(head)
     return ExtractedConstraints(conjuncts, constraints)
@@ -704,7 +717,10 @@ def _translate_link(
     return {"slots": slots, "vector": vector, "result": result}
 
 
-def _extract_constant_value(expr: expressions.Expression) -> t.Any:
+def _extract_constant_value(
+    expr: expressions.Expression,
+    parameters: t.Mapping[str, model.Expression],
+) -> t.Any:
     if isinstance(expr, expressions.IntegerConstant):
         return expr.integer
     elif isinstance(expr, expressions.BooleanConstant):
@@ -712,7 +728,17 @@ def _extract_constant_value(expr: expressions.Expression) -> t.Any:
     elif isinstance(expr, expressions.RealConstant):
         return expr.as_float
     elif isinstance(expr, expressions.ArrayValue):
-        return [_extract_constant_value(element) for element in expr.elements]
+        return [
+            _extract_constant_value(element, parameters) for element in expr.elements
+        ]
+    elif isinstance(expr, expressions.Name):
+        return _extract_constant_value(parameters[expr.identifier], parameters)
+    elif isinstance(expr, expressions.BinaryExpression) and hasattr(
+        expr.operator, "native_function"
+    ):
+        left = _extract_constant_value(expr.left, parameters)
+        right = _extract_constant_value(expr.right, parameters)
+        return expr.operator.native_function(left, right)
     else:
         raise CompileError(f"Unable to extract constant value from {expr}.")
 
@@ -721,12 +747,12 @@ def _update_initial_values(
     initial_values: _JSONObject,
     clock_constraints: t.List[_JSONObject],
     declarations: t.Iterable[VariableDeclaration],
+    parameters: t.Mapping[str, model.Expression],
 ) -> None:
     for declaration in declarations:
         initial_value = declaration.initial_value
         assert initial_value is not None
-        value = _extract_constant_value(initial_value)
-
+        value = _extract_constant_value(initial_value, parameters)
         if declaration.is_transient:
             continue
         elif declaration.typ == model.types.CLOCK:
@@ -759,6 +785,7 @@ def _translate_initial_states(
     ],
     declarations: Declarations,
     parameters: t.Mapping[str, model.Expression],
+    # ctx: _TranslationContext,
 ) -> t.List[_JSONObject]:
     initial_locations: t.Dict[str, str] = {}
     for instance, instance_name in instance_names.items():
@@ -769,11 +796,17 @@ def _translate_initial_states(
     initial_values: _JSONObject = {}
     clock_constraints: t.List[_JSONObject] = []
     _update_initial_values(
-        initial_values, clock_constraints, declarations.globals_table.values()
+        initial_values,
+        clock_constraints,
+        declarations.globals_table.values(),
+        parameters,
     )
     for variable_declarations in declarations.locals_table.values():
         _update_initial_values(
-            initial_values, clock_constraints, variable_declarations.values()
+            initial_values,
+            clock_constraints,
+            variable_declarations.values(),
+            parameters,
         )
     # for declaration in declarations.all_declarations:
     #     if declaration.typ != model.types.CLOCK:
@@ -847,6 +880,7 @@ def _translate_network(
                 instance_to_location_names,
                 declarations,
                 parameters,
+                # ctx #added
             ),
         },
         indent=2,
