@@ -18,10 +18,9 @@ from ..utils import checks
 from ..metadata import version
 
 
-# XXX: ignore this type definition, mypy does not support recursive types
-JSON = t.Union[None, int, float, str, t.Sequence["JSON"], t.Mapping[str, "JSON"]]  # type: ignore
+JSON = t.Union[None, int, float, str, t.Sequence["JSON"], t.Mapping[str, "JSON"]]
 
-_JANIMap = t.Dict[str, JSON]  # type: ignore
+_JANIMap = t.Dict[str, JSON]
 
 
 class ModelFeature(enum.Enum):
